@@ -3,7 +3,7 @@ import os
 import time
 from numpy.random import randint
 
-from ..al4nlp.utils import utils_tasks as utils
+from al4nlp.utils import utils_tasks as utils
 
 import logging
 
